@@ -206,8 +206,9 @@ void AbstractXMLObjectUnmarshaller::unmarshallContent(const DOMElement* domEleme
         else if (childNode->getNodeType() == DOMNode::TEXT_NODE || childNode->getNodeType() == DOMNode::CDATA_SECTION_NODE) {
             m_log.debug("processing text content at position (%d)", position);
             setTextContent(childNode->getNodeValue(), position);
-        } else if (childNode->getNodeType() == DOMNode::ENTITY_REFERENCE_NODE || childNode->getNodeType() == DOMNode::ENTITY_NODE) {
-            throw UnmarshallingException("Unmarshaller found Entity/Reference node.");
+        }
+        else if (childNode->getNodeType() != DOMNode::ATTRIBUTE_NODE) {
+            throw UnmarshallingException("Unmarshaller found unsupported node type.");
         }
         
         childNode = childNode->getNextSibling();
